@@ -440,9 +440,10 @@ int main(int argc, char **argv) {
     // Main game
     play();
 
-    hgw_context_compat_destroy_deinit(hgw_context);
+    // hgw_context_compat_destroy_deinit(hgw_context);
     // hgw_context_compat_destroy_quit(hgw_context);
     // hgw_context_destroy(hgw_context);
+    hgw_context_destroy(hgw_context, HGW_BYE_INACTIVE);
 
     return 0;
 }
